==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/WebCardMediaDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebCardMediaDescription } from "./WebCardMediaDescription";
/**
 * @hidden
 */
var WebCardMediaDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebCardMediaDescriptionMetadata, _super);
    function WebCardMediaDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebCardMediaDescriptionMetadata.b = function (a) {
        if (WebCardMediaDescriptionMetadata.a == null) {
            WebCardMediaDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebCardMediaDescriptionMetadata.c(WebCardMediaDescriptionMetadata.a);
        }
        if (a.j(WebCardMediaDescriptionMetadata.a)) {
            return;
        }
        a.y(WebCardMediaDescriptionMetadata.a);
    };
    WebCardMediaDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:CardMedia");
        a.item("__tagNameWC", "String:igc-card-media");
    };
    WebCardMediaDescriptionMetadata.d = function (a) {
        WebCardMediaDescriptionMetadata.b(a);
        a.aa("WebCardMedia", function () { return new WebCardMediaDescription(); });
        a.z("WebCardMedia", WebCardMediaDescriptionMetadata.a);
    };
    WebCardMediaDescriptionMetadata.$t = markType(WebCardMediaDescriptionMetadata, 'WebCardMediaDescriptionMetadata');
    WebCardMediaDescriptionMetadata.a = null;
    return WebCardMediaDescriptionMetadata;
}(Base));
export { WebCardMediaDescriptionMetadata };

==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/WebCardMediaDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebCardMediaDescription } from "./WebCardMediaDescription";
/**
 * @hidden
 */
var WebCardMediaDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebCardMediaDescriptionMetadata, _super);
    function WebCardMediaDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebCardMediaDescriptionMetadata.b = function (a) {
        if (WebCardMediaDescriptionMetadata.a == null) {
            WebCardMediaDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebCardMediaDescriptionMetadata.c(WebCardMediaDescriptionMetadata.a);
        }
        if (a.k(WebCardMediaDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebCardMediaDescriptionMetadata.a);
    };
    WebCardMediaDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:CardMedia");
        a.item("__tagNameWC", "String:igc-card-media");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
    };
    WebCardMediaDescriptionMetadata.d = function (a) {
        WebCardMediaDescriptionMetadata.b(a);
        a.ac("WebCardMedia", function () { return new WebCardMediaDescription(); });
        a.ab("WebCardMedia", WebCardMediaDescriptionMetadata.a);
    };
    WebCardMediaDescriptionMetadata.$t = markType(WebCardMediaDescriptionMetadata, 'WebCardMediaDescriptionMetadata');
    WebCardMediaDescriptionMetadata.a = null;
    return WebCardMediaDescriptionMetadata;
}(Base));
export { WebCardMediaDescriptionMetadata };
